@@ -6,6 +6,7 @@ globalVariables(
     "predict", "predicted_cluster", "printer", "rand_id",
     "distribution", "dist_data", "density", "density_data", "density_obj", "df",
     "dist_supported", "stats_func", "value", "x", "y", "sd", "key", "fct_rev",
-    "component", "terms", "pos_neg", "abs_value", "Positive?", "name"
+    "component", "terms", "pos_neg", "abs_value", "Positive?", "name","abort",
+    "xend","yend"
   )
 )
