@@ -27,14 +27,14 @@
 #' @examples
 #' suppressPackageStartupMessages(library(dplyr))
 #'
-#' len_out    = 25
-#' by_unit    = "month"
-#' start_date = as.Date("2021-01-01")
+#' len_out <- 25
+#' by_unit <- "month"
+#' start_date <- as.Date("2021-01-01")
 #'
 #' data_tbl <- tibble(
 #'   date_col = seq.Date(from = start_date, length.out = len_out, by = by_unit),
-#'   a    = rnorm(len_out),
-#'   b    = runif(len_out)
+#'   a = rnorm(len_out),
+#'   b = runif(len_out)
 #' )
 #'
 #' vec_1 <- hai_hyperbolic_vec(data_tbl$b, .scale_type = "sin")
@@ -52,29 +52,27 @@
 #' @export
 #'
 
-hai_hyperbolic_vec <- function(.x, .scale_type = c("sin","cos","tan","sincos")){
+hai_hyperbolic_vec <- function(.x, .scale_type = c("sin", "cos", "tan", "sincos")) {
+  if (inherits(x = .x, "Date")) {
+    x_term <- as.numeric(.x) %>% as.integer()
+  } else if (inherits(x = .x, "POSIXct")) {
+    x_term <- as.numeric(.x) %>% as.integer()
+  } else {
+    x_term <- .x
+  }
 
-    if(inherits(x = .x, "Date")){
-        x_term <- as.numeric(.x) %>% as.integer()
-    } else if(inherits(x = .x, "POSIXct")) {
-        x_term <- as.numeric(.x) %>% as.integer()
-    } else {
-        x_term <- .x
-    }
+  scale_type <- base::as.character(.scale_type)
+  term <- x_term
 
-    scale_type = base::as.character(.scale_type)
-    term       = x_term
-
-    if (scale_type == "sin"){
-        ret <- base::sin(term)
-    } else if (scale_type == "cos") {
-        ret <- base::cos(term)
-    } else if (scale_type == "tan") {
-        ret <- base::tan(term)
-    } else if (scale_type == "sincos") {
-        ret <- base::sin(term) * base::cos(term)
-    }
-
-    return(ret)
+  if (scale_type == "sin") {
+    ret <- base::sin(term)
+  } else if (scale_type == "cos") {
+    ret <- base::cos(term)
+  } else if (scale_type == "tan") {
+    ret <- base::tan(term)
+  } else if (scale_type == "sincos") {
+    ret <- base::sin(term) * base::cos(term)
+  }
 
+  return(ret)
 }
